@@ -4,5 +4,11 @@ TYPED_DATA_COLLECTION = "TypedDataCollection"
 RPC_HTTP_BODY_ONLY = "RpcHttpBodyOnly"
 RPC_HTTP_TRIGGER_METADATA_REMOVED = "RpcHttpTriggerMetadataRemoved"
 
+# Debug Flags
+PYAZURE_WEBHOST_DEBUG = "PYAZURE_WEBHOST_DEBUG"
+
 # Feature Flags (app settings)
 PYTHON_ROLLBACK_CWD_PATH = "PYTHON_ROLLBACK_CWD_PATH"
+
+# External Site URLs
+MODULE_NOT_FOUND_TS_URL = "https://aka.ms/functions-modulenotfound"
