@@ -30,9 +30,11 @@ import re
 import grpc
 import requests
 
-from . import aio_compat
+from azure_functions_worker._thirdparty import aio_compat
 from . import dispatcher
 from . import protos
+from .utils.common import is_envvar_true
+from .constants import PYAZURE_WEBHOST_DEBUG
 
 
 PROJECT_ROOT = pathlib.Path(__file__).parent.parent
@@ -127,17 +129,17 @@ class WebHostTestCaseMeta(type(unittest.TestCase)):
     def __new__(mcls, name, bases, dct):
         for attrname, attr in dct.items():
             if attrname.startswith('test_') and callable(attr):
-                test_case_name = attrname.lstrip('test_')
                 test_case = attr
-
-                check_log_case_name = f'check_log_{test_case_name}'
-                check_log_case = dct.get(check_log_case_name)
+                check_log_name = attrname.replace('test_', 'check_log_', 1)
+                check_log_case = dct.get(check_log_name)
 
                 @functools.wraps(test_case)
                 def wrapper(self, *args, __meth__=test_case,
                             __check_log__=check_log_case, **kwargs):
+                    if (__check_log__ is not None
+                            and callable(__check_log__)
+                            and not is_envvar_true(PYAZURE_WEBHOST_DEBUG)):
 
-                    if __check_log__ is not None and callable(__check_log__):
                         # Check logging output for unit test scenarios
                         result = self._run_test(__meth__, *args, **kwargs)
 
@@ -177,7 +179,7 @@ class WebHostTestCase(unittest.TestCase, metaclass=WebHostTestCaseMeta):
     @classmethod
     def setUpClass(cls):
         script_dir = pathlib.Path(cls.get_script_dir())
-        if os.environ.get('PYAZURE_WEBHOST_DEBUG'):
+        if is_envvar_true(PYAZURE_WEBHOST_DEBUG):
             cls.host_stdout = None
         else:
             cls.host_stdout = tempfile.NamedTemporaryFile('w+t')
@@ -660,7 +662,7 @@ def start_webhost(*, script_dir=None, stdout=None):
         script_root = FUNCS_PATH
 
     if stdout is None:
-        if os.environ.get('PYAZURE_WEBHOST_DEBUG'):
+        if is_envvar_true(PYAZURE_WEBHOST_DEBUG):
             stdout = sys.stdout
         else:
             stdout = subprocess.DEVNULL
