@@ -3,6 +3,7 @@ import subprocess
 import sys
 import typing
 import tempfile
+import unittest
 
 from azure_functions_worker import protos
 from azure_functions_worker import testutils
@@ -51,10 +52,18 @@ class TestGRPC(testutils.AsyncTestCase):
         test_env = {}
         await self._verify_environment_reloaded(test_env=test_env)
 
+    @unittest.skipIf(sys.platform == 'darwin',
+                     'MacOS creates the processes specific var folder in '
+                     '/private filesystem and not in /var like in linux '
+                     'systems.')
     async def test_changing_current_working_directory(self):
         test_cwd = tempfile.gettempdir()
         await self._verify_environment_reloaded(test_cwd=test_cwd)
 
+    @unittest.skipIf(sys.platform == 'darwin',
+                     'MacOS creates the processes specific var folder in '
+                     '/private filesystem and not in /var like in linux '
+                     'systems.')
     async def test_reload_env_message(self):
         test_env = {'TEST_KEY': 'foo', 'HELLO': 'world'}
         test_cwd = tempfile.gettempdir()
@@ -78,11 +87,15 @@ class TestGRPC(testutils.AsyncTestCase):
         finally:
             self._reset_environ()
 
+    @unittest.skipIf(sys.platform == 'win32',
+                     'Linux .sh script only works on Linux')
     def test_failed_sys_path_import(self):
         self._verify_sys_path_import(
             'fail',
             "No module named 'test_module'")
 
+    @unittest.skipIf(sys.platform == 'win32',
+                     'Linux .sh script only works on Linux')
     def test_successful_sys_path_import(self):
         self._verify_sys_path_import(
             'success',
@@ -90,6 +103,7 @@ class TestGRPC(testutils.AsyncTestCase):
 
     def _verify_azure_namespace_import(self, result, expected_output):
         try:
+            print(os.getcwd())
             path_import_script = os.path.join(
                 testutils.UNIT_TESTS_ROOT,
                 'azure_namespace_import',
@@ -105,11 +119,15 @@ class TestGRPC(testutils.AsyncTestCase):
         finally:
             self._reset_environ()
 
+    @unittest.skipIf(sys.platform == 'win32',
+                     'Linux .sh script only works on Linux')
     def test_failed_azure_namespace_import(self):
         self._verify_azure_namespace_import(
             'false',
             'module_b fails to import')
 
+    @unittest.skipIf(sys.platform == 'win32',
+                     'Linux .sh script only works on Linux')
     def test_successful_azure_namespace_import(self):
         self._verify_azure_namespace_import(
             'true',
